@@ -1069,7 +1069,7 @@ def runProcessFull(outLoc, refLoc, refGenome):
     hist_file = outLoc + '/initial/allHistBam_100k.npz' #originaly 10k
     chr_file = outLoc + '/initial/allChr_100k.npz' #originaly 10k
     uniqueCell_file = outLoc + '/initial/cellNames.npz'
-    #cellDoSmallBinning(read_folder, hist_file, chr_file, uniqueCell_file)
+    cellDoSmallBinning(read_folder, hist_file, chr_file, uniqueCell_file)
 
 
 
@@ -1082,7 +1082,7 @@ def runProcessFull(outLoc, refLoc, refGenome):
     chr_file = outLoc + '/initial/allChr_100k.npz'
     rawHAP_file = outLoc + '/initial/allRawHAP_100k.npz'
     uniqueCell_file = outLoc + '/initial/cellNames.npz'
-    #doHapSmallBinning(name_file, uniqueCell_file, nameOld_folder, hap_folder, chr_file, rawHAP_file)
+    doHapSmallBinning(name_file, uniqueCell_file, nameOld_folder, hap_folder, chr_file, rawHAP_file)
 
 
     hist_file = outLoc + '/initial/allHistBam_100k.npz' #used to be 10k
@@ -1101,7 +1101,7 @@ def runProcessFull(outLoc, refLoc, refGenome):
     #if folder1 == 'DLP':
     #    lowHapDoImbalance = True
 
-    #findGCadjustment(refGenome, refLoc, hist_file, adjustment_file, chr_file, lowHapDoImbalance, rawHAP_file, hapHist_file,  chr_file2, goodSubset_file, RDR_file, totalRead_file)
+    findGCadjustment(refGenome, refLoc, hist_file, adjustment_file, chr_file, lowHapDoImbalance, rawHAP_file, hapHist_file,  chr_file2, goodSubset_file, RDR_file, totalRead_file)
 
 
     
