@@ -1,4 +1,5 @@
 import os
+import subprocess
 
 #os.system('ls')
 #quit()
@@ -6,6 +7,7 @@ import os
 import numpy as np
 from pathlib import Path
 import sys
+import time
 
 #from raw import countReads
 
@@ -44,12 +46,12 @@ def loadnpz(name, allow_pickle=False):
 
 
 
+
 def systemPrint(command1):
 
     print (command1)
-    os.system(command1)
-
-
+    #os.system(command1)
+    subprocess.run(command1, shell=True)
 
 
 def makeAllDirectories(name):
@@ -58,7 +60,7 @@ def makeAllDirectories(name):
     command1 = 'mkdir ' + name
     systemPrint(command1)
 
-    
+    systemPrint(command1 + '/temp')
     systemPrint(command1 + '/counts')
     systemPrint(command1 + '/info')
     systemPrint(command1 + '/phased')
@@ -68,6 +70,7 @@ def makeAllDirectories(name):
     systemPrint(command1 + '/initial')
     systemPrint(command1 + '/binScale')
     systemPrint(command1 + '/model')
+    
 
     
     for chrNum in range(1, 22+1):
@@ -79,6 +82,51 @@ def makeAllDirectories(name):
 #quit()
 
 
+def runParallel(commandList, outLoc):
+
+    #Different operating systems have different issues in terms of running commands and waiting for them to complete
+    #This simple "hack" ensures the command has completed before moving on. 
+
+    randomInt = np.random.randint(1000000000)
+
+    tempLoc = outLoc + '/temp/'
+    tempFileList = []
+    commandList2 = []
+    for a in range(len(commandList)):
+        tempFile = tempLoc + str(randomInt) + '_' + str(a) + '.txt'
+        command2 = ' ( ' + commandList[a] + ' ; touch ' + tempFile + ' ) '
+        commandList2.append(command2)
+        tempFileList.append(tempFile)
+    
+    commandFull = '&'.join(commandList2)
+
+    systemPrint(commandFull)
+    #os.popen(commandFull).read()
+    #print (commandFull)
+
+    wait1 = True
+    while wait1:
+        print ('')
+        wait1 = False
+        for file1 in tempFileList:
+            if not os.path.exists(file1):
+                wait1 = True
+                print ('nope')
+                print (file1)
+
+        if wait1:
+            time.sleep(10)
+    
+    for file1 in tempFileList:
+        commandRemove = 'rm ' + file1
+        systemPrint(commandRemove)
+    
+
+
+
+
+
+
 def addReadGroup(dataName):
 
     samtoolsLocation = '/scratch/data/stefan/stefanSoftware/samtools_1.17/bin/samtools'
@@ -355,18 +403,18 @@ def loadReference(chrNum):
 
     link1 = 'http://ftp.1000genomes.ebi.ac.uk/vol1/ftp/release/20130502/' + originalName
     command1 = 'wget ' + link1
-    os.system(command1)
+    systemPrint(command1)
     command2 = 'mv ./' + originalName +  ' ./data/reference/vcf/chr' + chrNum + '.vcf.gz' + tbiPart
-    os.system(command2)
+    systemPrint(command2)
     #quit()
 
     tbiPart = '.tbi'
     originalName = 'ALL.chr' + chrNum + '.phase3_shapeit2_mvncall_integrated_' + vname + '.20130502.genotypes.vcf.gz' + tbiPart
     link1 = 'http://ftp.1000genomes.ebi.ac.uk/vol1/ftp/release/20130502/' + originalName
     command1 = 'wget ' + link1
-    os.system(command1)
+    systemPrint(command1)
     command2 = 'mv ./' + originalName +  ' ./data/reference/vcf/chr' + chrNum + '.vcf.gz' + tbiPart
-    os.system(command2)
+    systemPrint(command2)
 
 
 #loadReference('X')
@@ -457,7 +505,11 @@ def findCombinedCounts(bamLoc, refLoc, outLoc, refGenome):
     #    refName = 'hg19'
 
     commandList1 = []
-    commandList2 = []
+
+    commandList_1 = []
+    commandList_2 = []
+
+    checkFiles = []
 
     command1 = ''
     for a in range(1, 22+1):
@@ -478,21 +530,56 @@ def findCombinedCounts(bamLoc, refLoc, outLoc, refGenome):
             refFasta = refLoc + '/hg19.fa'
             renameRef = refLoc + '/vcf_hg19/chr' + chrNum + '.vcf.gz'
 
+        checkFiles.append(countsFile + '.tbi')
+
 
         command1 = 'bcftools mpileup --ignore-RG -Ou -R ' + renameRef + ' -f ' + refFasta + ' ' + bamLoc + ' | bcftools call -vmO z -o ' + countsFile
-        commandList1.append(command1)
+        commandList_1.append(command1)
 
         command2 = 'bcftools index -t ' + countsFile
-        commandList2.append(command2)
+        commandList_2.append(command2)
+
+        command1 = ' ( ' + command1 + ' ; ' + command2 + ' ) '
+
+        commandList1.append(command1)
 
     
-    commandFull1 = ' & '.join(commandList1)
-    systemPrint(commandFull1)
-    commandFull2 = ' & '.join(commandList2)
-    systemPrint(commandFull2)
 
-    #systemPrint(command1)
-    True
+    if False:
+        commandFull1 = ' & '.join(commandList1)
+        systemPrint(commandFull1)
+
+        #runParallel(commandList1, outLoc)
+        
+        
+        #commandFull2 = ' & '.join(commandList2)
+        #systemPrint(commandFull2)
+
+        #for a in range(len(commandList2)):
+        #    command2 = commandList2[a]
+        #    systemPrint(command2)
+
+        wait1 = True
+        while wait1:
+            print ('')
+            wait1 = False
+            for file1 in checkFiles:
+                if not os.path.exists(file1):
+                    print (file1)
+                    print ('nope')
+                    wait1 = True
+
+            if wait1:
+                time.sleep(10)
+
+
+
+
+        #systemPrint(command1)
+        True
+
+    runParallel(commandList_1, outLoc)
+    runParallel(commandList_2, outLoc)
 
 
 
@@ -508,6 +595,8 @@ def runPhasing(outLoc, refGenome, refLoc):
     #    refName = 'hg19'
 
     #command1 = ''
+    commandList1 = []
+    commandList2 = []
     for a in range(1, 22+1):
         chrNum = str(a)
 
@@ -531,11 +620,27 @@ def runPhasing(outLoc, refGenome, refLoc):
         command6_output = ' --output ' + phasedFile + ' --thread 8'
         
         command6 = command6_input + command6_output
-        systemPrint(command6)
+        #systemPrint(command6)
+        commandList1.append(command6)
 
         command7 = 'bcftools index -t ' + str(phasedFile) 
 
-        systemPrint(command7)
+        #systemPrint(command7)
+        commandList2.append(command7)
+
+    
+    if False:
+        commandFull1 = ' & '.join(commandList1)
+        systemPrint(commandFull1)
+        #commandFull2 = ' & '.join(commandList2)
+        #systemPrint(commandFull2)
+
+        for a in range(len(commandList2)):
+            command2 = commandList2[a]
+            systemPrint(command2)
+
+    runParallel(commandList1, outLoc)
+    runParallel(commandList2, outLoc)
 
 
 
@@ -613,7 +718,9 @@ def findIndividualCounts(bamLoc, refLoc, outLoc, refGenome):
     #else:
     #    refName = 'hg19'
 
-    command1 = ''
+    #command1 = ''
+
+    commandList1 = []
     for a in range(1, 22+1):
         chrNum = str(a)
 
@@ -633,7 +740,13 @@ def findIndividualCounts(bamLoc, refLoc, outLoc, refGenome):
         countsFile = outLoc + '/counts/seperates_chr' + chrNum + '.vcf.gz'
         
         command1 = 'bcftools mpileup --annotate FORMAT/AD -Ou -R ' + restrictedFile + ' -f ' + refFasta + ' ' + bamLoc + ' | bcftools call -vmO z -o ' + countsFile
-        systemPrint(command1)
+        #systemPrint(command1)
+        commandList1.append(command1)
+    
+    #commandFull1 = ' & '.join(commandList1)
+    #systemPrint(commandFull1)
+
+    runParallel(commandList1, outLoc)
     
 
 
@@ -903,7 +1016,7 @@ def ACTsplitter():
 
             command1 = 'samtools index ' + folder1 + fnames[a]
 
-            os.system(command1)
+            systemPrint(command1)
 
 #ACTsplitter()
 #quit()
@@ -1175,7 +1288,7 @@ def findHaplotypeCounts(chrNum, outLoc):
     np.savez_compressed(outLoc + '/phasedCounts/barcodes_chr' + chrNum + '.npz', barcodes)
     np.savez_compressed(outLoc + '/phasedCounts/positions_chr' + chrNum + '.npz', positionsHap)
 
-    quit()
+    #quit()
 
 
 
@@ -1601,7 +1714,6 @@ def runAllSteps(bamLoc, refLoc, outLoc, refGenome):
 
     runAllGroupedEvidenceSVD(outLoc)
 
-    #runProcessFull(outLoc, refLoc, refGenome)
 
 
 #for a in range(1, 23):
