@@ -18,11 +18,10 @@ from torch.optim import Optimizer
 
 #import seaborn as sns
 
-#from shared import *
-
-from .shared import *
-
-
+if __name__ == "__main__":
+    from shared import *
+else:
+    from .shared import *
 
 
 
@@ -30,6 +29,9 @@ from .shared import *
 
 
 
+predCNA = loadnpz('/Users/stefanivanovic/Desktop/Coding/Bio/CNA/data/TN3_example/model/pred_now.npz')
+haplotypePlotter(predCNA, doCluster=True)
+quit()
 
 
 
@@ -2499,10 +2501,13 @@ initialUniqueIndex_file = './data/' + folder1 + '/binScale/initialIndex.npz'
 #quit()
 
 
-def saveReformatCSV(outLoc):
+def saveReformatCSV(outLoc, isNaive=False):
 
-    pred1 = loadnpz(outLoc + '/model/pred_now.npz')
-    naive1 = loadnpz(outLoc + '/binScale/initialCNA.npz')
+    if isNaive:
+        pred1 = loadnpz(outLoc + '/binScale/initialCNA.npz')
+    else:
+        pred1 = loadnpz(outLoc + '/model/pred_now.npz')
+    
     goodSubset = loadnpz(outLoc + '/initial/subset.npz')
     chr1 = loadnpz(outLoc + '/initial/chr_100k.npz')
     chrAll = loadnpz(outLoc + '/initial/allChr_100k.npz')
@@ -2537,23 +2542,27 @@ def saveReformatCSV(outLoc):
         posIndexing.append([chrome, startPos, endPos])
         #print (posIndexing[-1]) 
 
-    dataAll = [['Cell barcode', 'Chromsome', 'Start', 'End', 'Haplotype 1', 'Haplotype 2']]
+    dataAll = [['Cell barcode', 'Chromosome', 'Start', 'End', 'Haplotype 1', 'Haplotype 2']]
 
     for a in range(pred1.shape[0]):
         for b in range(pred1.shape[1]):
             dataAll.append( [ cellNames[a], posIndexing[b][0], posIndexing[b][1], posIndexing[b][2], int(pred1[a][b][0]), int(pred1[a][b][1])  ] )
     
     dataAll = np.array(dataAll)
-    outFile = outLoc + '/finalPrediction/DeepCopyPrediction.csv'
+    if isNaive:
+        outFile = outLoc + '/finalPrediction/NaiveCopyPrediction.csv'
+    else:
+        outFile = outLoc + '/finalPrediction/DeepCopyPrediction.csv'
     np.savetxt(outFile, dataAll, delimiter=",", fmt='%s')
 
-    naiveAll = [['Cell barcode', 'Chromsome', 'Start', 'End', 'Haplotype 1', 'Haplotype 2']]
-    for a in range(naive1.shape[0]):
-        for b in range(naive1.shape[1]):
-            naiveAll.append( [ cellNames[a], posIndexing[b][0], posIndexing[b][1], posIndexing[b][2], int(naive1[a][b][0]), int(naive1[a][b][1])  ] )
-    naiveAll = np.array(naiveAll)
-    naiveFile = outLoc + '/finalPrediction/NaiveCopyPrediction.csv'
-    np.savetxt(naiveFile, naiveAll, delimiter=",", fmt='%s')
+    #naiveAll = [['Cell barcode', 'Chromosome', 'Start', 'End', 'Haplotype 1', 'Haplotype 2']]
+    #for a in range(naive1.shape[0]):
+    #    for b in range(naive1.shape[1]):
+    #        naiveAll.append( [ cellNames[a], posIndexing[b][0], posIndexing[b][1], posIndexing[b][2], int(naive1[a][b][0]), int(naive1[a][b][1])  ] )
+    #naiveAll = np.array(naiveAll)
+    #naiveFile = outLoc + '/finalPrediction/NaiveCopyPrediction.csv'
+    #np.savetxt(naiveFile, naiveAll, delimiter=",", fmt='%s')
+    True
 
 
 
@@ -2573,7 +2582,8 @@ def saveReformatCSV(outLoc):
 
 
 
-def scalorRunAll(outLoc):
+
+def scalorRunBins(outLoc):
     
 
     chr_file = outLoc + '/initial/chr_100k.npz'
@@ -2600,6 +2610,13 @@ def scalorRunAll(outLoc):
 
 
 
+
+
+def runNaiveCopy(outLoc):
+    
+
+    
+
     chr_file = outLoc + '/initial/chr_1M.npz'
     RDR_file = outLoc + '/initial/RDR_1M.npz'
     region_file = outLoc + '/binScale/regions.npz'
@@ -2633,9 +2650,18 @@ def scalorRunAll(outLoc):
     findInitialCNA(RDR_file, noise_file, BAF_file, BAF_noise_file, chr_file, divider_file, error_file, dividerList_file, initialCNA_file, initialUniqueCNA_file, initialUniqueIndex_file)
     
 
+    saveReformatCSV(outLoc, isNaive=True)
+
+
+def scalorRunAll(outLoc):
+    scalorRunBins(outLoc)
+    runNaiveCopy(outLoc)
 
 
 #outLoc = './data/newTN3'
 #scalorRunAll(outLoc)
 
-
+#outLoc = '/Users/stefanivanovic/Desktop/Coding/Bio/CNA/data/TN3'
+#saveReformatCSV(outLoc, isNaive=True)
+#saveReformatCSV(outLoc, isNaive=False)
+#quit()
\ No newline at end of file
